@@ -155,7 +155,7 @@ bool PascalImport::parseStmt()
         const QString& name = advance();
         UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package, name,
                                                       currentScope(), m_comment);
-        pushScope(static_cast<UMLPackage*>(ns));
+        pushScope(ns->asUMLPackage());
         skipStmt();
         return true;
     }
@@ -217,7 +217,7 @@ bool PascalImport::parseStmt()
     }
     if (keyword == QLatin1String("end")) {
         if (m_klass) {
-            m_klass = NULL;
+            m_klass = 0;
         } else if (scopeIndex()) {
             popScope();
             m_currentAccess = Uml::Visibility::Public;
@@ -229,7 +229,7 @@ bool PascalImport::parseStmt()
     }
     if (keyword == QLatin1String("function") || keyword == QLatin1String("procedure") ||
         keyword == QLatin1String("constructor") || keyword == QLatin1String("destructor")) {
-        if (m_klass == NULL) {
+        if (m_klass == 0) {
             // Unlike a Pascal unit, a UML package does not support subprograms.
             // In order to map those, we would need to create a UML class with
             // stereotype <<utility>> for the unit, http://bugs.kde.org/89167
@@ -311,7 +311,7 @@ bool PascalImport::parseStmt()
         skipStmt();
         return true;
     }
-    if (m_klass == NULL) {
+    if (m_klass == 0) {
         const QString& name = m_source[m_srcIndex];
         QString nextToken = advance();
         if (nextToken != QLatin1String("=")) {
@@ -323,7 +323,7 @@ bool PascalImport::parseStmt()
             // enum type
             UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Enum,
                             name, currentScope(), m_comment);
-            UMLEnum *enumType = static_cast<UMLEnum*>(ns);
+            UMLEnum *enumType = ns->asUMLEnum();
             while (++m_srcIndex < srcLength && m_source[m_srcIndex] != QLatin1String(")")) {
                 Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex]);
                 if (advance() != QLatin1String(","))
@@ -353,15 +353,15 @@ bool PascalImport::parseStmt()
                                                                          : UMLObject::ot_Interface);
             UMLObject *ns = Import_Utils::createUMLObject(t, name,
                                                           currentScope(), m_comment);
-            UMLClassifier *klass = static_cast<UMLClassifier*>(ns);
+            UMLClassifier *klass = ns->asUMLClassifier();
             m_comment.clear();
             QString lookAhead = m_source[m_srcIndex + 1];
             if (lookAhead == QLatin1String("(")) {
                 advance();
                 do {
                     QString base = advance();
-                    UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Class, base, NULL);
-                    UMLClassifier *parent = static_cast<UMLClassifier*>(ns);
+                    UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Class, base, 0);
+                    UMLClassifier *parent = ns->asUMLClassifier();
                     m_comment.clear();
                     Import_Utils::createGeneralization(klass, parent);
                 } while (advance() == QLatin1String(","));
@@ -388,7 +388,7 @@ bool PascalImport::parseStmt()
             UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Class, name,
                                                           currentScope(), m_comment);
             ns->setStereotype(QLatin1String("record"));
-            m_klass = static_cast<UMLClassifier*>(ns);
+            m_klass = ns->asUMLClassifier();
             return true;
         }
         if (keyword == QLatin1String("function") || keyword == QLatin1String("procedure")) {
@@ -403,7 +403,7 @@ bool PascalImport::parseStmt()
         return false;
     }
     // At this point we need a class because we're expecting its member attributes.
-    if (m_klass == NULL) {
+    if (m_klass == 0) {
         uDebug() << "importPascal: skipping " << m_source[m_srcIndex];
         skipStmt();
         return true;
@@ -432,7 +432,7 @@ bool PascalImport::parseStmt()
     }
     UMLObject *o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
                                                  typeName, m_comment);
-    UMLAttribute *attr = static_cast<UMLAttribute*>(o);
+    UMLAttribute *attr = o->asUMLAttribute();
     attr->setStereotype(stereotype);
     attr->setInitialValue(initialValue);
     skipStmt();
