@@ -26,12 +26,17 @@
 #include "entityattribute.h"
 #include "object_factory.h"
 
+#if QT_VERSION < 0x050000
 #include <kdialogbuttonbox.h>
-#include <klocale.h>
+#endif
+#include <KLocalizedString>
+#if QT_VERSION < 0x050000
 #include <ktabwidget.h>
+#endif
 #include <ktextedit.h>
 
 #include <QApplication>
+#include <QDialogButtonBox>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QListWidget>
@@ -200,12 +205,22 @@ void ClassifierListPage::setupMoveButtons(QHBoxLayout* parentLayout)
  */
 void ClassifierListPage::setupActionButtons(const QString& itemType, QVBoxLayout* parentLayout)
 {
+#if QT_VERSION >= 0x050000
+    QDialogButtonBox* buttonBox = new QDialogButtonBox(m_pItemListGB);
+    m_pNewClassifierListItemButton = buttonBox->addButton(itemType, QDialogButtonBox::ActionRole);
+    connect(m_pNewClassifierListItemButton, SIGNAL(clicked()), this, SLOT(slotNewListItem()));
+    m_pDeleteListItemButton = buttonBox->addButton(i18n("&Delete"), QDialogButtonBox::ActionRole);
+    connect(m_pDeleteListItemButton, SIGNAL(clicked()), this, SLOT(slotDelete()));
+    m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), QDialogButtonBox::ActionRole);
+    connect(m_pPropertiesButton, SIGNAL(clicked()), this, SLOT(slotProperties()));
+#else
     KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pItemListGB);
     m_pNewClassifierListItemButton = buttonBox->addButton(itemType, KDialogButtonBox::ActionRole, this,
                           SLOT(slotNewListItem()));
     m_pDeleteListItemButton = buttonBox->addButton(i18n("&Delete"),
                               KDialogButtonBox::ActionRole, this, SLOT(slotDelete()));
     m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), KDialogButtonBox::ActionRole, this, SLOT(slotProperties()));
+#endif
     parentLayout->addWidget(buttonBox);
 }
 
@@ -222,7 +237,11 @@ void ClassifierListPage::setupDocumentationGroup(int margin)
     if (m_itemType == UMLObject::ot_Operation) {
         m_docTE = new KTextEdit();
         m_pCodeTE = new CodeTextEdit();
+#if QT_VERSION >= 0x050000
+        QTabWidget* tabWidget = new QTabWidget();
+#else
         KTabWidget* tabWidget = new KTabWidget();
+#endif
         tabWidget->addTab(m_docTE, i18n("Comment"));
         tabWidget->addTab(m_pCodeTE, i18n("Source Code"));
         docLayout->addWidget(tabWidget);
@@ -318,7 +337,7 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
     if (m_pOldListItem) {
         m_pOldListItem->setDoc(m_docTE->toPlainText());
         if (m_itemType == UMLObject::ot_Operation) {
-            UMLOperation* op = dynamic_cast<UMLOperation*>(m_pOldListItem);
+            UMLOperation* op = m_pOldListItem->asUMLOperation();
             op->setSourceCode(m_pCodeTE->toPlainText());
         }
     }
@@ -332,7 +351,7 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
     UMLClassifierListItemList itemList = getItemList();
     int itemIndex;
 
-    if (item == NULL) {
+    if (item == 0) {
         if (m_pItemListLB->count() == 0) {
             enableWidgets(false);
             m_pOldListItem = 0;
@@ -352,7 +371,12 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
         // now update screen
         m_docTE->setText(listItem->doc());
         if (m_itemType == UMLObject::ot_Operation) {
-            m_pCodeTE->setPlainText(dynamic_cast<UMLOperation*>(listItem)->getSourceCode());
+            UMLOperation* o = listItem->asUMLOperation();
+            if (!o) {
+                uError() << "Dynamic cast to UMLOperation failed for" << listItem->name();
+                return;
+            }
+            m_pCodeTE->setPlainText(o->getSourceCode());
         }
         enableWidgets(true);
         m_pOldListItem = listItem;
@@ -377,8 +401,8 @@ void ClassifierListPage::slotListItemCreated(UMLObject* object)
     if (!m_bSigWaiting) {
         return;
     }
-    UMLClassifierListItem *listItem = dynamic_cast<UMLClassifierListItem*>(object);
-    if (listItem == NULL)  {
+    UMLClassifierListItem *listItem = object->asUMLClassifierListItem();
+    if (listItem == 0)  {
         return;
     }
 
@@ -529,7 +553,7 @@ void ClassifierListPage::slotTopClicked()
     //shouldn't occur, but just in case
     if(count <= 1 || index <= 0)
         return;
-    m_pOldListItem = NULL;
+    m_pOldListItem = 0;
 
     //swap the text around in the ListBox
     QString currentString = m_pItemListLB->item(index)->text();
@@ -563,7 +587,7 @@ void ClassifierListPage::slotUpClicked()
     //shouldn't occur, but just in case
     if (count <= 1 || index <= 0)
         return;
-    m_pOldListItem = NULL;
+    m_pOldListItem = 0;
 
     //swap the text around in the ListBox
     QString aboveString = m_pItemListLB->item(index - 1)->text();
@@ -600,7 +624,7 @@ void ClassifierListPage::slotDownClicked()
     //shouldn't occur, but just in case
     if (count <= 1 || index >= count - 1 || index == -1)
         return;
-    m_pOldListItem = NULL;
+    m_pOldListItem = 0;
 
     //swap the text around in the ListBox
     QString belowString = m_pItemListLB->item(index + 1)->text();
@@ -636,7 +660,7 @@ void ClassifierListPage::slotBottomClicked()
     //shouldn't occur, but just in case
     if (count <= 1 || index >= count - 1 || index == -1)
         return;
-    m_pOldListItem = NULL;
+    m_pOldListItem = 0;
 
     //swap the text around in the ListBox
     QString currentString = m_pItemListLB->item(index)->text();
@@ -700,7 +724,7 @@ void ClassifierListPage::slotDelete()
         m_doc->removeUMLObject(selectedItem);
         m_pOldListItem = 0;
 
-        slotActivateItem(NULL);
+        slotActivateItem(0);
     }
 }
 
@@ -743,7 +767,7 @@ void ClassifierListPage::saveCurrentItemDocumentation()
     if (selectedItem) {
         selectedItem->setDoc(m_docTE->toPlainText());
         if (m_itemType == UMLObject::ot_Operation) {
-            dynamic_cast<UMLOperation*>(selectedItem)->setSourceCode(m_pCodeTE->toPlainText());
+            selectedItem->asUMLOperation()->setSourceCode(m_pCodeTE->toPlainText());
         }
     }
 }
@@ -767,29 +791,55 @@ bool ClassifierListPage::addClassifier(UMLClassifierListItem* listitem, int posi
 {
     switch (m_itemType) {
     case UMLObject::ot_Attribute: {
-            UMLAttribute *att = dynamic_cast<UMLAttribute*>(listitem);
-            return m_pClassifier->addAttribute(att, NULL, position);
+            UMLAttribute *att = listitem->asUMLAttribute();
+            if (!att) {
+                uError() << "Dynamic cast to UMLAttribute failed for" << listitem->name();
+                return false;
+            }
+            return m_pClassifier->addAttribute(att, 0, position);
         }
     case UMLObject::ot_Operation: {
-            UMLOperation *op = dynamic_cast<UMLOperation*>(listitem);
+            UMLOperation *op = listitem->asUMLOperation();
+            if (!op) {
+                uError() << "Dynamic cast to UMLOperation failed for" << listitem->name();
+                return false;
+            }
             return m_pClassifier->addOperation(op, position);
         }
     case UMLObject::ot_Template: {
-            UMLTemplate* t = dynamic_cast<UMLTemplate*>(listitem);
+            UMLTemplate* t = listitem->asUMLTemplate();
+            if (!t) {
+                uError() << "Dynamic cast to UMLTemplate failed for" << listitem->name();
+                return false;
+            }
             return m_pClassifier->addTemplate(t, position);
         }
     case UMLObject::ot_EnumLiteral: {
-            UMLEnum* c = dynamic_cast<UMLEnum*>(m_pClassifier);
-            if (c) {
-                return c->addEnumLiteral(dynamic_cast<UMLEnumLiteral*>(listitem), position);
+            UMLEnum* c = m_pClassifier->asUMLEnum();
+            if (!c) {
+                uError() << "Dynamic cast to UMLEnum failed for" << m_pClassifier->name();
+                return false;
             }
+            UMLEnumLiteral *l = listitem->asUMLEnumLiteral();
+            if (!l) {
+                uError() << "Dynamic cast to UMLEnumLiteral failed for" << listitem->name();
+                return false;
+            }
+            return c->addEnumLiteral(l, position);
             break;
         }
     case UMLObject::ot_EntityAttribute: {
-            UMLEntity* c = dynamic_cast<UMLEntity*>(m_pClassifier);
-            if (c) {
-                return c->addEntityAttribute(dynamic_cast<UMLEntityAttribute*>(listitem), position);
+            UMLEntity* c = m_pClassifier->asUMLEntity();
+            if (!c) {
+                uError() << "Dynamic cast to UMLEntity failed for" << m_pClassifier->name();
+                return false;
             }
+            UMLEntityAttribute *a = listitem->asUMLEntityAttribute();
+            if (!a) {
+                uError() << "Dynamic cast to UMLEntityAttribute failed for" << listitem->name();
+                return false;
+            }
+            return c->addEntityAttribute(a, position);
             break;
         }
     default: {
@@ -858,5 +908,4 @@ void ClassifierListPage::hideArrowButtons(bool hide)
     m_pBottomArrowB->setVisible(state) ;
 }
 
-#include "classifierlistpage.moc"
 
